==> django-jutil-2.2.6.tar.gz: django-jutil-2.2.6/jutil/bank_const_se.py <==
SE_BANK_CLEARING_LIST = (  # 46
    ('Svea Bank', '9660', '9669', 7),
    ('Avanza Bank', '9550', '9569', 7),
    ('Bluestep Finans AB', '9680', '9689', 7),
    ('BNP Paribas Fortis SA/NV', '9470', '9470', 7),
    ('Citibank', '9040', '9049', 7),
    ('Danske Bank', '1200', '1399', 7),
    ('Danske Bank', '2400', '2499', 7),
    ('Danske Bank', '9180', '9189', 7),
    ('Den Norske Bank', '9190', '9199', 7),
    ('Ekobanken', '9700', '9709', 7),
    ('Erik Penser Bankaktiebolag', '9590', '9599', 7),
    ('Forex Bank AB', '9400', '9449', 7),
    ('JAK Medlemsbank', '9670', '9679', 7),
    ('Santander Consumer Bank AS', '9460', '9469', 7),
    ('Handelsbanken', '6000', '6999', 9),
    ('ICA Banken AB', '9270', '9279', 7),
    ('IKANO Banken AB', '9170', '9179', 7),
    ('Landshypotek AB', '9390', '9399', 7),
    ('Länsförsäkringar Bank AB', '9020', '9029', 7),
    ('Länsförsäkringar Bank AB', '3400', '3409', 7),
    ('Länsförsäkringar Bank AB', '9060', '9069', 7),
    ('Lån og Spar Bank Sverige', '9630', '9639', 7),
    ('Marginalen Bank', '9230', '9239', 7),
    ('Med Mera Bank AB', '9650', '9659', 7),
    ('Nordax Bank AB', '9640', '9649', 7),
    ('Nordea AB', '1100', '1199', 7),
    ('Nordea AB', '1449', '1999', 7),
    ('Nordea AB', '3000', '3299', 7),
    ('Nordea AB Personkonto', '3300', '3300', 10),
    ('Nordea AB', '3301', '3399', 7),
    ('Nordea AB', '4000', '4999', 7),
    ('Nordea AB', '1401', '1448', 7),
    ('Nordea AB', '2000', '2099', 7),
    ('Nordea AB', '9500', '9549', 10),
    ('Nordea AB', '9960', '9969', 10),
    ('Nordnet Bank', '9100', '9109', 7),
    ('Resurs Bank AB', '9280', '9289', 7),
    ('Riksgälden', '9880', '9889', 7),
    ('Royal Bank of Scotland', '9090', '9099', 7),
    ('SBAB Bank AB', '9250', '9259', 7),
    ('SEB', '5000', '5999', 7),
    ('SEB', '9120', '9124', 7),
    ('SEB', '9130', '9149', 7),
    ('Skandiabanken AB', '9150', '9169', 7),
    ('Sparbanken Syd', '9570', '9579', 10),
    ('Swedbank', '7000', '7999', 7),
    ('Swedbank', '8000', '8999', 10),
    ('Ålandsbanken Abp', '2300', '2399', 7),
)

==> django-jutil-3.0.8.tar.gz: django-jutil-3.0.8/jutil/bank_const_se.py <==
SE_BANK_CLEARING_LIST = (  # 46
    ('Nordea AB', '1100', '1199', 7),
    ('Danske Bank', '1200', '1399', 7),
    ('Nordea AB', '1401', '2099', 7),
    ('Ålandsbanken Abp', '2300', '2399', 7),
    ('Danske Bank', '2400', '2499', 7),
    ('Nordea AB', '3000', '3299', 7),
    ('Nordea AB Personkonto', '3300', '3300', 10),
    ('Nordea AB', '3301', '3399', 7),
    ('Länsförsäkringar Bank AB', '3400', '3409', 7),
    ('Nordea AB', '3460', '3599', 7),
    ('Nordea AB', '3600', '3999', 7),  # 3977
    ('Nordea AB', '4000', '4999', 7),
    ('SEB', '5000', '5999', 7),
    ('Handelsbanken', '6000', '6999', 9),
    ('Swedbank', '7000', '7999', 7),
    ('Swedbank', '8000', '8999', 8),  # Swedbank acc # can be 10 digits but clearing max 5
    ('Länsförsäkringar Bank AB', '9020', '9029', 7),
    ('Citibank', '9040', '9049', 7),
    ('Länsförsäkringar Bank AB', '9060', '9069', 7),
    ('Royal Bank of Scotland', '9090', '9099', 7),
    ('Nordnet Bank', '9100', '9109', 7),
    ('SEB', '9120', '9124', 7),
    ('SEB', '9130', '9149', 7),
    ('Skandiabanken AB', '9150', '9169', 7),
    ('IKANO Banken AB', '9170', '9179', 7),
    ('Danske Bank', '9180', '9189', 7),
    ('Den Norske Bank', '9190', '9199', 7),
    ('Marginalen Bank', '9230', '9239', 7),
    ('SBAB Bank AB', '9250', '9259', 7),
    ('ICA Banken AB', '9270', '9279', 7),
    ('Resurs Bank AB', '9280', '9289', 7),
    ('Landshypotek AB', '9390', '9399', 7),
    ('Forex Bank AB', '9400', '9449', 7),
    ('Santander Consumer Bank AS', '9460', '9469', 7),
    ('BNP Paribas Fortis SA/NV', '9470', '9470', 7),
    ('Nordea AB', '9500', '9549', 10),
    ('Avanza Bank', '9550', '9569', 7),
    ('Sparbanken Syd', '9570', '9579', 8),
    ('Erik Penser Bankaktiebolag', '9590', '9599', 7),
    ('Lån og Spar Bank Sverige', '9630', '9639', 7),
    ('Nordax Bank AB', '9640', '9649', 7),
    ('Med Mera Bank AB', '9650', '9659', 7),
    ('Svea Bank', '9660', '9669', 7),
    ('JAK Medlemsbank', '9670', '9679', 7),
    ('Bluestep Finans AB', '9680', '9689', 7),
    ('Ekobanken', '9700', '9709', 7),
    ('Riksgälden', '9880', '9889', 7),
    ('Nordea AB', '9960', '9969', 10),
)
